@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2016-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2016-2021 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 import warnings
 
@@ -208,7 +208,7 @@ class FitModel(object):
                 else:
                     self.zord = 1
                 if self.logscale:
-                    self.ax.set_yscale("log", nonposy='clip')
+                    self.ax.set_yscale("log")
                 self.fline = None
 
             def showplot(self, xlab=self.lmodel.xlabelstr,
