@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2013-2016 Dominik Kriegner <dominik.kriegner@gmail.com>
+ * Copyright (C) 2013-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
  * Copyright (C) 2013 Eugen Wintersberger <eugen.wintersberger@desy.de>
  *
 */
@@ -57,6 +57,9 @@ extern PyObject* ang2q_detpos_area(PyObject *self, PyObject *args);
 /* functions from file_io.c */
 extern PyObject* cbfread(PyObject *self, PyObject *args);
 
+/* functions from hklcond.c */
+extern PyObject* testhklcond(PyObject *self, PyObject *args);
+
 static PyMethodDef XRU_Methods[] = {
     {"block_average1d", (PyCFunction)block_average1d, METH_VARARGS,
      "block average for one-dimensional numpy double array\n\n"
@@ -273,7 +276,7 @@ static PyMethodDef XRU_Methods[] = {
      "                   of investigated crystal (9)\n"
      " sampledis ....... sample displacement vector in same unit as the\n"
      "                   detector distance\n"
-     " lambda .......... wavelength of the used x-rays in Angstroem\n"
+     " lambda .......... wavelength of the used x-rays in angstrom\n"
      " nthreads ........ number of threads to use in parallel section of the\n"
      "                   code\n"
      " flags ........... integer flags to select sub-function\n"
@@ -486,10 +489,21 @@ static PyMethodDef XRU_Methods[] = {
      " -------\n"
      "  the parsed data values as float ndarray\n"
     },
+    {"testhklcond", testhklcond, METH_VARARGS,
+     "test if a Bragg peak is allowed according to reflection conditions\n\n"
+     " Parameters\n"
+     " ----------\n"
+     "  hkl :           Miller indices of the peak to test (integer array)\n"
+     "  condgeneral :   General reflection conditions (list of tuples)\n"
+     "  condwp :        Reflection conditions for Wyckoff positions\n"
+     "                  (list of list of tuples)\n\n"
+     " Returns\n"
+     " -------\n"
+     " bool : True if peak is allowed, False otherwise\n"
+    },
     {NULL, NULL, 0, NULL}        /* Sentinel */
 };
 
-#if PY_MAJOR_VERSION >= 3
 static struct PyModuleDef moduledef = {
     PyModuleDef_HEAD_INIT,
     "cxrayutilities",  /* m_name */
@@ -502,28 +516,13 @@ static struct PyModuleDef moduledef = {
     NULL,              /* m_clear */
     NULL,              /* m_free */
 };
-#endif
 
-PyMODINIT_FUNC
-#if PY_MAJOR_VERSION >= 3
-PyInit_cxrayutilities(void)
-#else
-initcxrayutilities(void)
-#endif
+PyMODINIT_FUNC PyInit_cxrayutilities(void)
 {
     PyObject *m;
-
-    #if PY_MAJOR_VERSION >= 3
     m = PyModule_Create(&moduledef);
-    #else
-    m = Py_InitModule3("cxrayutilities", XRU_Methods,
-        "Python C extension including performance critical parts\n"
-        "of xrayutilities (gridder, qconversion, block-averageing)\n");
-    #endif
 
     import_array();
 
-    #if PY_MAJOR_VERSION >= 3
     return m;
-    #endif
 }
